# conda-store server

[![Documentation Status](https://readthedocs.org/projects/conda-store/badge/?version=latest)](https://conda-store.readthedocs.io/en/latest/?badge=latest)

A multi-tenant server for managing Conda environments. See the
[documentation](https://conda-store.readthedocs.io/en/latest/) for
more information.
